/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __SCREEN_CONNECTOR_TOOLKIT_H__
#define __SCREEN_CONNECTOR_TOOLKIT_H__

#include <wayland-client.h>
#include <wayland-tbm-client.h>
#include <aul_screen_connector.h>
#ifdef __cplusplus
extern "C" {
#endif

typedef enum {
	SCREEN_CONNECTOR_INPUT_TYPE_MOUSE_UP_DOWN = TIZEN_REMOTE_SURFACE_INPUT_EVENT_FILTER_MOUSE_UP_DOWN,
	SCREEN_CONNECTOR_INPUT_TYPE_MOUSE_MOVE_X = TIZEN_REMOTE_SURFACE_INPUT_EVENT_FILTER_MOUSE_MOVE_X,
	SCREEN_CONNECTOR_INPUT_TYPE_MOUSE_MOVE_Y = TIZEN_REMOTE_SURFACE_INPUT_EVENT_FILTER_MOUSE_MOVE_Y,
	SCREEN_CONNECTOR_INPUT_TYPE_MOUSE_MOVE_X_Y = TIZEN_REMOTE_SURFACE_INPUT_EVENT_FILTER_MOUSE_MOVE_X_Y,
	SCREEN_CONNECTOR_INPUT_TYPE_MOUSE_WHEEL = TIZEN_REMOTE_SURFACE_INPUT_EVENT_FILTER_MOUSE_WHEEL_ALL,
	SCREEN_CONNECTOR_INPUT_TYPE_TOUCH_UP_DOWN = TIZEN_REMOTE_SURFACE_INPUT_EVENT_FILTER_TOUCH_UP_DOWN,
	SCREEN_CONNECTOR_INPUT_TYPE_TOUCH_MOVE_X = TIZEN_REMOTE_SURFACE_INPUT_EVENT_FILTER_TOUCH_MOVE_X,
	SCREEN_CONNECTOR_INPUT_TYPE_TOUCH_MOVE_Y = TIZEN_REMOTE_SURFACE_INPUT_EVENT_FILTER_TOUCH_MOVE_Y,
	SCREEN_CONNECTOR_INPUT_TYPE_TOUCH_MOVE_X_Y = TIZEN_REMOTE_SURFACE_INPUT_EVENT_FILTER_TOUCH_MOVE_X_Y,
	SCREEN_CONNECTOR_INPUT_TYPE_TOUCH_CANCEL = TIZEN_REMOTE_SURFACE_INPUT_EVENT_FILTER_TOUCH_CANCEL_ALL,
	SCREEN_CONNECTOR_INPUT_TYPE_KEY = TIZEN_REMOTE_SURFACE_INPUT_EVENT_FILTER_KEY_ALL,
} screen_connector_input_type_e;

typedef enum {
	SCREEN_CONNECTOR_SCREEEN_TYPE_WIDGET = AUL_SCREEN_TYPE_WIDGET,
	SCREEN_CONNECTOR_SCREEEN_TYPE_WATCH = AUL_SCREEN_TYPE_WATCH,
	SCREEN_CONNECTOR_SCREEEN_TYPE_UI = AUL_SCREEN_TYPE_UI,
	SCREEN_CONNECTOR_SCREEEN_TYPE_ALL = AUL_SCREEN_TYPE_ALL,
} screen_connector_screen_type_e;

typedef void (*screen_connector_toolkit_added_cb)(const char *appid, const char *instance_id, const int pid, void *data);
typedef void (*screen_connector_toolkit_removed_cb)(const char *appid, const char *instance_id, const int pid, void *data);
typedef void (*screen_connector_toolkit_update_cb)(struct tizen_remote_surface *trs, uint32_t type, struct wl_buffer *tbm,
		int32_t img_file_fd, uint32_t img_file_size, uint32_t time, struct wl_array *keys,
		const char *appid, const char *instance_id, const int pid, void *data);

typedef struct _screen_connector_toolkit_ops {
	screen_connector_toolkit_added_cb added_cb;
	screen_connector_toolkit_removed_cb removed_cb;
	screen_connector_toolkit_update_cb updated_cb;
} screen_connector_toolkit_ops;

typedef struct _screen_connector_toolkit_h *screen_connector_toolkit_h;
typedef struct _screen_connector_type_h *screen_connector_type_h;

int screen_connector_toolkit_init(screen_connector_screen_type_e type);
int screen_connector_toolkit_fini(screen_connector_screen_type_e type);
screen_connector_toolkit_h screen_connector_toolkit_add(screen_connector_toolkit_ops *ops, char *id,
	screen_connector_screen_type_e type, void *data);
int screen_connector_toolkit_remove(screen_connector_toolkit_h h);
int screen_connector_toolkit_update(const char *appid, const char *instance_id);
const char *screen_connector_toolkit_get_appid(screen_connector_toolkit_h h);
const char *screen_connector_toolkit_get_instance_id(screen_connector_toolkit_h h);
int screen_connector_toolkit_get_pid(screen_connector_toolkit_h h);
int screen_connector_toolkit_get_surface_id(screen_connector_toolkit_h h);
void *screen_connector_toolkit_get_user_data(screen_connector_toolkit_h h);

unsigned int screen_connector_toolkit_get_event_filter(screen_connector_toolkit_h h);
int screen_connector_toolkit_check_input_disabled(screen_connector_toolkit_h h,	screen_connector_input_type_e input);
screen_connector_toolkit_h screen_connector_toolkit_create_handle(char *id, int surface_id,
	screen_connector_toolkit_ops *ops, void *data);
struct tizen_remote_surface *screen_connector_toolkit_get_trs(screen_connector_toolkit_h h);
int screen_connector_toolkit_redirect_surface(screen_connector_toolkit_h info);
screen_connector_toolkit_h screen_connector_toolkit_add_with_surface(screen_connector_toolkit_ops *ops, char *id,
	screen_connector_screen_type_e type, struct wl_surface *surface, void *data);

#ifdef __cplusplus
}
#endif

#endif /* __SCREEN_CONNECTOR_WATCHER_H__ */
